fnss.traffic.trafficmatrices.TrafficMatrixSequence.insert — FNSS 0.3.2 documentation

### Navigation

- index
- modules |
- modules |
- FNSS 0.3.2 documentation »

# fnss.traffic.trafficmatrices.TrafficMatrixSequence.insert

`TrafficMatrixSequence.` `insert`(i, tm)

  Insert a traffic matrix in the sequence at a specified position

  Parameters : | i : int The position at which the matrix is inserted tm : TrafficMatrix The traffic matrix to insert

### Navigation

- index
- modules |
- modules |
- FNSS 0.3.2 documentation »